***********************************
The sherpa.astro.xspec.utils module
***********************************

.. currentmodule:: sherpa.astro.xspec.utils

.. automodule:: sherpa.astro.xspec.utils

This module provides routines useful for the
:doc:`XSPEC model <xspec_model>` interface.

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      ModelMeta

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      include_if
      version_at_least
